==> rucy-0.4.0.tar.gz: rucy-0.4.0/lib_conf/rucy/config_core.rb <==
# $Id: config_core.rb,v 1.4 2004/12/23 03:34:05 toki Exp $

require 'rucy/rc_d'
require 'rucy/priv'
require 'rucy/passwd'
require 'rucy/loader'
require 'rucy/document'
require 'rucy/restart'
require 'rucy/messenger'
require 'rucy/server'

module Rucy
  module Config
    def config_core(rep)
      # for rucy/rc_d
      rep.set_value(:Daemon, Daemon)
      rep.set_value(:ProcessProbe, ProcessProbe)
      rep.set_block(:RC_d) {
	RC_d.new(RC_d::LOCK_FILE, rep)
      }

      # for rucy/priv
      rep.set_block(:Privilege) {|non_privilege_user, non_privilege_group|
	Privilege.new(non_privilege_user, non_privilege_group, rep)
      }

      # for rucy/passwd
      rep.set_block(:PasswordEncryptor) { PasswordEncryptor.new(rep) }

      # for rucy/loader
      rep.set_class(:ModuleLoader, SimpleLoader)
      rep.set_class(:ModuleFolder, ModuleFolder)

      # for rucy/document
      rep.set_class(:DocumentFactory, DocumentFactory)
      rep.set_block(:DocumentLoader) {|mod_path| DocumentLoader.new(mod_path, rep) }

      # for rucy/restart
      rep.set_class(:MultiThreadRestartSignal, MultiThreadRestartSignal)
      rep.set_class(:MultiProcessRestartSignal, MultiProcessRestartSignal)

      # for rucy/messenger
      rep.set_value(:MultiThreadMessengerClass, MultiThreadMessenger)
      rep.set_value(:MultiProcessMessengerClass, MultiProcessMessenger)

      # for rucy/server
      rep.set_block(:Server) { Server.new(rep) }

      rep
    end
    module_function :config_core
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/lib_conf/rucy/config_core.rb <==
# $Id: config_core.rb,v 1.7 2005/02/11 16:24:53 toki Exp $

require 'rucy/rc_d'
require 'rucy/priv'
require 'rucy/passwd'
require 'rucy/loader'
require 'rucy/document'
require 'rucy/restart'
require 'rucy/messenger'
require 'rucy/server'
require 'rucy/config'

module Rucy
  module Config
    def config_core(rep)
      # for rucy/rc_d
      rep.set_value(:Daemon_module, Daemon)
      rep.set_value(:ProcessProbe_module, ProcessProbe)
      rep.set_block(:RC_d) {
	RC_d.new(RC_d::LOCK_FILE, rep)
      }

      # for rucy/priv
      rep.set_block(:Privilege) {|non_privilege_user, non_privilege_group|
	Privilege.new(non_privilege_user, non_privilege_group, rep)
      }

      # for rucy/passwd
      rep.set_block(:PasswordEncryptor) { PasswordEncryptor.new(rep) }

      # for rucy/loader
      rep.set_class(:ModuleLoader, SimpleLoader)
      rep.set_class(:ModuleFolder, ModuleFolder)

      # for rucy/document
      rep.set_class(:DocumentFactory, DocumentFactory)
      rep.set_block(:DocumentLoader) {|mod_path| DocumentLoader.new(mod_path, rep) }

      # for rucy/restart
      rep.set_class(:MultiThreadRestartSignal, MultiThreadRestartSignal)
      rep.set_class(:MultiProcessRestartSignal, MultiProcessRestartSignal)

      # for rucy/messenger
      rep.set_value(:MultiThreadMessenger_class, MultiThreadMessenger)
      rep.set_value(:MultiProcessMessenger_class, MultiProcessMessenger)

      # for rucy/server
      rep.set_block(:Server) { Server.new(rep) }

      rep
    end
    module_function :config_core

    setup{|rep| config_core(rep) }
  end
end
